@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* nv_pair.h - the opkg package management system
 
    Carl D. Worth
@@ -23,17 +24,15 @@ extern "C" {
 #endif
 
 typedef struct nv_pair nv_pair_t;
-struct nv_pair
-{
+struct nv_pair {
     char *name;
     char *value;
 };
 
-int nv_pair_init(nv_pair_t *nv_pair, const char *name, const char *value);
-void nv_pair_deinit(nv_pair_t *nv_pair);
+int nv_pair_init(nv_pair_t * nv_pair, const char *name, const char *value);
+void nv_pair_deinit(nv_pair_t * nv_pair);
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif /* NV_PAIR_H */
+#endif                          /* NV_PAIR_H */
