@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* opkg_cmd.h - the opkg package management system
 
    Carl D. Worth
@@ -22,24 +23,22 @@
 extern "C" {
 #endif
 
-typedef int (*opkg_cmd_fun_t)(int argc, const char **argv);
+typedef int (*opkg_cmd_fun_t) (int argc, const char **argv);
 
-struct opkg_cmd
-{
+struct opkg_cmd {
     const char *name;
     int requires_args;
     opkg_cmd_fun_t fun;
-    unsigned int pfm; /* package field mask */
+    unsigned int pfm;       /* package field mask */
 };
 typedef struct opkg_cmd opkg_cmd_t;
 
 opkg_cmd_t *opkg_cmd_find(const char *name);
-int opkg_cmd_exec(opkg_cmd_t *cmd, int argc, const char **argv);
+int opkg_cmd_exec(opkg_cmd_t * cmd, int argc, const char **argv);
 
 extern int opkg_state_changed;
 
 #ifdef __cplusplus
 }
 #endif
-
-#endif /* OPKG_CMD_H */
+#endif                          /* OPKG_CMD_H */
