@@ -25,7 +25,6 @@
 #include <fcntl.h>
 #include <glob.h>
 #include <unistd.h>
-#include <malloc.h>
 #include <stdlib.h>
 
 #include "opkg_conf.h"
@@ -90,6 +89,7 @@ static opkg_option_t options[] = {
     {"combine", OPKG_OPT_TYPE_BOOL, &_conf.combine},
     {"cache_local_files", OPKG_OPT_TYPE_BOOL, &_conf.cache_local_files},
     {"verbose_status_file", OPKG_OPT_TYPE_BOOL, &_conf.verbose_status_file},
+    {"compress_list_files", OPKG_OPT_TYPE_BOOL, &_conf.compress_list_files},
 #if defined(HAVE_GPGME)
     {"gpg_dir", OPKG_OPT_TYPE_STRING, &_conf.gpg_dir},
     {"gpg_trust_level", OPKG_OPT_TYPE_STRING, &_conf.gpg_trust_level},
@@ -481,6 +481,32 @@ static int opkg_conf_parse_file(const char *filename,
     return err;
 }
 
+static int skip_pkg_if_duplicate_and_installed(pkg_t *pkg)
+{
+    int i;
+    int skip = 0;
+
+    /*  If a pkg is set to be installed, but another version is already installed
+     *  then skip  */
+    if ((pkg->state_status == SS_NOT_INSTALLED) && (pkg->state_want == SW_INSTALL)) {
+        pkg_t *installed_pkg;
+        pkg_vec_t *installed_pkgs = pkg_vec_alloc();
+        pkg_hash_fetch_all_installed(installed_pkgs, INSTALLED_HALF_INSTALLED);
+
+        for (i = 0; i < installed_pkgs->len; i++) {
+            installed_pkg = installed_pkgs->pkgs[i];
+            if (!strcmp(installed_pkg->name, pkg->name)) {
+                skip = 1;
+                break;
+            }
+        }
+
+        pkg_vec_free(installed_pkgs);
+    }
+
+    return skip;
+}
+
 int opkg_conf_write_status_files(void)
 {
     pkg_dest_list_elt_t *iter;
@@ -524,7 +550,7 @@ int opkg_conf_write_status_files(void)
                      pkg->name);
             continue;
         }
-        if (pkg->dest->status_fp)
+        if (pkg->dest->status_fp && !skip_pkg_if_duplicate_and_installed(pkg))
             pkg_print_status(pkg, pkg->dest->status_fp);
     }
 
