@@ -19,10 +19,10 @@
 
 #include "config.h"
 
-#include <malloc.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <libgen.h>
 
 #include "opkg_download.h"
 #include "opkg_message.h"
