@@ -19,7 +19,7 @@
 #include "config.h"
 
 #include <curl/curl.h>
-#include <malloc.h>
+#include <stdlib.h>
 #include <ctype.h>
 #include <stddef.h>
 #include <string.h>
