@@ -16,7 +16,7 @@
 
 #include "config.h"
 
-#include <malloc.h>
+#include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
 
