@@ -22,6 +22,7 @@
 #include <ctype.h>
 #include <string.h>
 #include <stdio.h>
+#include <stdlib.h>
 
 #include "opkg_message.h"
 #include "opkg_utils.h"
@@ -38,7 +39,12 @@ int is_field(const char *type, const char *line)
 
 char *parse_simple(const char *type, const char *line)
 {
-    return trim_xstrdup(line + strlen(type) + 1);
+    char *field = trim_xstrdup(line + strlen(type) + 1);
+    if (strlen(field) == 0) {
+	    free(field);
+	    return NULL;
+    }
+    return field;
 }
 
 /*
