@@ -20,7 +20,7 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <malloc.h>
+#include <stdlib.h>
 
 #include "pkg_dest.h"
 #include "file_util.h"
