@@ -18,7 +18,7 @@
 
 #include "config.h"
 
-#include <malloc.h>
+#include <stdlib.h>
 
 #include "opkg_message.h"
 #include "xregex.h"
