@@ -1,3 +1,4 @@
+/* vi: set expandtab sw=4 sts=4: */
 /* xsystem.h - system(3) with error messages
 
    Carl D. Worth
@@ -18,7 +19,9 @@
 #ifndef XSYSTEM_H
 #define XSYSTEM_H
 
-#include <stdlib.h>
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 /* Like system(3), but with error messages printed if the fork fails
    or if the child process dies due to an uncaught signal. Also, the
@@ -30,5 +33,7 @@
 */
 int xsystem(const char *argv[]);
 
+#ifdef __cplusplus
+}
 #endif
-	 
+#endif                          /* XSYSTEM_H */
