@@ -1,4 +1,4 @@
-#! /usr/bin/env python
+#! /usr/bin/env python3
 #
 # Install a package B, which recommends package A. Verify that A installs
 # automatically and gets flagged as auto-installed. Make a newer version
@@ -34,7 +34,7 @@ o.write_opk()
 o.write_list()
 
 opkgcl.update()
-opkgcl.upgrade("--autoremove")
+opkgcl.upgrade("b", "--autoremove")
 
 if opkgcl.is_installed("a"):
-	opk.xfail("[libsolv] Package a should have been auto-removed")
+	opk.fail("Package a should have been auto-removed")
