@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#! /usr/bin/env python3
 #
 # Reporter: Graham Gower
 #
@@ -7,7 +7,7 @@
 #
 # 1. Create package a version 1, containing file /foo.
 # 2. Create package a version 2, without file /foo, depending on package b.
-# 3. Create package b version 1, containing file /foo.
+# 3. Create package b version 1, containing file /foo which Conflicts  a (<< 2.0)
 # 4. Create package repository containing a_2 and b_1.
 # 5. Install a_1 manually.
 # 6. opkg update; opkg upgrade
@@ -42,7 +42,7 @@ opkgcl.install("a_1.0_all.opk")
 o = opk.OpkGroup()
 a2 = opk.Opk(Package="a", Version="2.0", Depends="b")
 a2.write()
-b1 = opk.Opk(Package="b", Version="1.0")
+b1 = opk.Opk(Package="b", Version="1.0", Conflicts="a (<< 2.0)", Replaces="a (<< 2.0)")
 b1.write(data_files=["foo"])
 o.opk_list.append(a2)
 o.opk_list.append(b1)
@@ -51,7 +51,10 @@ o.write_list()
 os.unlink("foo")
 
 opkgcl.update()
-opkgcl.upgrade()
+status = opkgcl.upgrade("a")
+
+if status != 0:
+        opk.fail("Upgrade operation failed (Return value was different than 0)")
 
 if not opkgcl.is_installed("a", "2.0"):
 	opk.fail("Package 'a_2.0' not installed.")
@@ -59,7 +62,7 @@ if not opkgcl.is_installed("a", "2.0"):
 foo_fullpath = "{}/foo".format(cfg.offline_root)
 
 if not os.path.exists(foo_fullpath):
-	opk.xfail("[libsolv] File 'foo' incorrectly orphaned.")
+	opk.fail("File 'foo' incorrectly orphaned.")
 
 if not foo_fullpath in opkgcl.files("b"):
 	opk.fail("Package 'b' does not own file 'foo'.")
