@@ -1,4 +1,4 @@
-#!/usr/bin/python3
+#! /usr/bin/env python3
 #
 # Reporter: Graham Gower
 #
@@ -34,6 +34,6 @@ opkgcl.update()
 opkgcl.install("c")
 if not opkgcl.is_installed("c"):
 	cleanup()
-	opk.xfail("package ``c'' not installed.")
+	opk.xfail("[internalsolv] package ``c'' not installed.")
 
 cleanup()
